;; Generated package description from cond-let.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "cond-let" "1.0.0" "Additional and improved binding conditionals" '((emacs "28.1")) :commit "28d3b039a9c1f27ecfea36a7df4c37a3b90e4687" :keywords '("extensions") :url "https://github.com/tarsius/cond-let")
